lang_dict = {
    "Eski Türkçe": {
        "name": "Eski Türkçe",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_Turkic",
        "era": "600—1200",
    },
    "Orta Türkçe": {
        "name": "Orta Türkçe",
        "wiki_link": "https://en.wikipedia.org/wiki/Middle_Turkic_languages",
        "era": "900—1500",
    },
    "Eski Yunanca": {
        "name": "Antik Yunanca",
        "wiki_link": "https://en.wikipedia.org/wiki/Ancient_Greek",
        "era": "MÖ.1500—MS.300",
    },
    "Orta Farsça": {
        "name": "Orta Farsça",
        "wiki_link": "https://en.wikipedia.org/wiki/Middle_Persian",
        "era": "1300—1500",
    },
    "Akatça": {
        "name": "Akatça",
        "wiki_link": "https://en.wikipedia.org/wiki/Akkadian_language",
        "era": "MÖ.2500—MÖ.500",
    },
    "Avestaca": {
        "name": "Avestaca",
        "wiki_link": "https://en.wikipedia.org/wiki/Avestan",
        "era": "MÖ.2000",
    },
    "Eski Fransızca": {
        "name": "Eski Fransızca",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_French",
        "era": "842—1400",
    },
    "Eski İngilizce": {
        "name": "Eski İngilizce",
        "wiki_link": "https://en.wikipedia.org/wiki/Old_English",
        "era": "450—1150",
    },
    "Soğdca": {
        "name": "Soğdca",
        "wiki_link": "https://en.wikipedia.org/wiki/Sogdian_language",
        "era": "MÖ.1000—MS.1000",
    },
    "Hintavrupa Anadili": {
        "name": "Hintavrupa Anadili",
        "wiki_link": "https://en.wikipedia.org/wiki/Proto-Indo-European_language",
        "era": "MS.4500—MS.2500",
    },
}
