cache = {
    "books": [
        {"book_id": 1, "book_code": "q", "book_display": "Kuran kaynaklı ad"},
        {"book_id": 2, "book_code": "s", "book_display": "Sahabi adı"},
        {"book_id": 3, "book_code": "ş", "book_display": "Şahname kaynaklı ad"},
        {"book_id": 4, "book_code": "t", "book_display": "Tevrat kaynaklı ad"},
        {
            "book_id": 5,
            "book_code": "t q",
            "book_display": "Tevrat ve Kuran kaynaklı ad",
        },
        {"book_id": 6, "book_code": "yt", "book_display": "Yeni Türk adı (1934-35)"},
        {
            "book_id": 7,
            "book_code": "q s",
            "book_display": "Kuran kaynaklı ad, sahabi adı",
        },
        {"book_id": 8, "book_code": "i", "book_display": "İncil kaynaklı ad"},
        {
            "book_id": 9,
            "book_code": "t i",
            "book_display": "Tevrat ve İncil kaynaklı ad",
        },
        {
            "book_id": 10,
            "book_code": "i q",
            "book_display": "İncil ve Kuran kaynaklı ad",
        },
        {"book_id": 11, "book_code": "d", "book_display": "Dede Korkut kaynaklı ad"},
    ],
    "languages": [
        {
            "lang_id": 1,
            "lang_code": "a",
            "lang_display": "Ar",
            "lang_fullname": "Arapça",
        },
        {
            "lang_id": 2,
            "lang_code": "alm",
            "lang_display": "Alm",
            "lang_fullname": "Almanca",
        },
        {
            "lang_id": 3,
            "lang_code": "arn",
            "lang_display": "Arn",
            "lang_fullname": "Arnavutça",
        },
        {
            "lang_id": 4,
            "lang_code": "az",
            "lang_display": "Az",
            "lang_fullname": "Azerice",
        },
        {
            "lang_id": 5,
            "lang_code": "bu",
            "lang_display": "Bul",
            "lang_fullname": "Bulgarca",
        },
        {
            "lang_id": 6,
            "lang_code": "ç",
            "lang_display": "Çr",
            "lang_fullname": "Çerkesçe",
        },
        {
            "lang_id": 7,
            "lang_code": "çin",
            "lang_display": "Çin",
            "lang_fullname": "Çince",
        },
        {
            "lang_id": 8,
            "lang_code": "coğ",
            "lang_display": "coğ",
            "lang_fullname": "Yer veya kavim adı",
        },
        {
            "lang_id": 9,
            "lang_code": "e",
            "lang_display": "Erm",
            "lang_fullname": "Ermenice",
        },
        {
            "lang_id": 10,
            "lang_code": "ealm",
            "lang_display": "EAlm",
            "lang_fullname": "Eski Almanca",
        },
        {
            "lang_id": 11,
            "lang_code": "eing",
            "lang_display": "Eİng",
            "lang_fullname": "Eski Anglosaksonca",
        },
        {
            "lang_id": 12,
            "lang_code": "f",
            "lang_display": "Fa",
            "lang_fullname": "Farsça",
        },
        {
            "lang_id": 13,
            "lang_code": "fr",
            "lang_display": "Fr",
            "lang_fullname": "Fransızca",
        },
        {
            "lang_id": 14,
            "lang_code": "g",
            "lang_display": "Gü",
            "lang_fullname": "Gürcüce",
        },
        {
            "lang_id": 15,
            "lang_code": "ger",
            "lang_display": "Ger",
            "lang_fullname": "Germence",
        },
        {
            "lang_id": 16,
            "lang_code": "h",
            "lang_display": "Hint",
            "lang_fullname": "Hintçe",
        },
        {
            "lang_id": 17,
            "lang_code": "ib",
            "lang_display": "İbr",
            "lang_fullname": "İbranice",
        },
        {
            "lang_id": 18,
            "lang_code": "ing",
            "lang_display": "İng",
            "lang_fullname": "İngilizce",
        },
        {
            "lang_id": 19,
            "lang_code": "irl",
            "lang_display": "İrl",
            "lang_fullname": "İrlandaca",
        },
        {
            "lang_id": 20,
            "lang_code": "isp",
            "lang_display": "İsp",
            "lang_fullname": "İspanyolca",
        },
        {
            "lang_id": 21,
            "lang_code": "isv",
            "lang_display": "İsv",
            "lang_fullname": "İsveççe",
        },
        {
            "lang_id": 22,
            "lang_code": "it",
            "lang_display": "İt",
            "lang_fullname": "İtalyanca",
        },
        {
            "lang_id": 23,
            "lang_code": "k",
            "lang_display": "Kr",
            "lang_fullname": "Kürtçe",
        },
        {
            "lang_id": 24,
            "lang_code": "kaz",
            "lang_display": "Kaz",
            "lang_fullname": "Kazakça",
        },
        {
            "lang_id": 25,
            "lang_code": "krg",
            "lang_display": "Krg",
            "lang_fullname": "Kırgızca",
        },
        {
            "lang_id": 26,
            "lang_code": "lat",
            "lang_display": "Lat",
            "lang_fullname": "Latince",
        },
        {
            "lang_id": 27,
            "lang_code": "lz",
            "lang_display": "Laz",
            "lang_fullname": "Lazca",
        },
        {
            "lang_id": 28,
            "lang_code": "mac",
            "lang_display": "Mac",
            "lang_fullname": "Macarca",
        },
        {
            "lang_id": 29,
            "lang_code": "moğ",
            "lang_display": "Moğ",
            "lang_fullname": "Moğolca",
        },
        {
            "lang_id": 30,
            "lang_code": "nor",
            "lang_display": "Nor",
            "lang_fullname": "Eski Norsça (Viking dili)",
        },
        {
            "lang_id": 31,
            "lang_code": "öz",
            "lang_display": "öz",
            "lang_fullname": "kişi adı",
        },
        {
            "lang_id": 32,
            "lang_code": "r",
            "lang_display": "Rus",
            "lang_fullname": "Rusça",
        },
        {
            "lang_id": 33,
            "lang_code": "ro",
            "lang_display": "Rom",
            "lang_fullname": "Romence",
        },
        {
            "lang_id": 34,
            "lang_code": "s",
            "lang_display": "Sür",
            "lang_fullname": "Süryanice",
        },
        {
            "lang_id": 35,
            "lang_code": "srp",
            "lang_display": "Srp",
            "lang_fullname": "Sırp/Hırvatça",
        },
        {
            "lang_id": 36,
            "lang_code": "t",
            "lang_display": "Tr",
            "lang_fullname": "Türkçe",
        },
        {
            "lang_id": 37,
            "lang_code": "x",
            "lang_display": "Tr+",
            "lang_fullname": "Türkçe (karışık)",
        },
        {
            "lang_id": 38,
            "lang_code": "yt",
            "lang_display": "YTr",
            "lang_fullname": "Yeni Türkçe",
        },
        {
            "lang_id": 39,
            "lang_code": "ef",
            "lang_display": "İr",
            "lang_fullname": "Eski İran dilleri",
        },
        {
            "lang_id": 40,
            "lang_code": "akad",
            "lang_display": "Akad",
            "lang_fullname": "Akatça",
        },
        {
            "lang_id": 41,
            "lang_code": "fen",
            "lang_display": "Fen",
            "lang_fullname": "Fenike dili",
        },
        {
            "lang_id": 42,
            "lang_code": "fin",
            "lang_display": "Fin",
            "lang_fullname": "Fince",
        },
        {
            "lang_id": 43,
            "lang_code": "tat",
            "lang_display": "Tat",
            "lang_fullname": "Tatarca",
        },
        {
            "lang_id": 44,
            "lang_code": "uk",
            "lang_display": "Ukr",
            "lang_fullname": "Ukrayna dili",
        },
        {
            "lang_id": 45,
            "lang_code": "ey",
            "lang_display": "EYun",
            "lang_fullname": "Eski Yunanca",
        },
        {
            "lang_id": 46,
            "lang_code": "y",
            "lang_display": "Yun",
            "lang_fullname": "Yunanca",
        },
        {
            "lang_id": 47,
            "lang_code": "mıs",
            "lang_display": "Mıs",
            "lang_fullname": "Eski Mısır dili",
        },
        {
            "lang_id": 48,
            "lang_code": "et",
            "lang_display": "ETr",
            "lang_fullname": "Eski Türkçe",
        },
        {
            "lang_id": 49,
            "lang_code": "ar",
            "lang_display": "Aram",
            "lang_fullname": "Arami/Süryanice",
        },
        {
            "lang_id": 52,
            "lang_code": "hol",
            "lang_display": "Hol",
            "lang_fullname": "Hollandaca",
        },
        {
            "lang_id": 54,
            "lang_code": "z",
            "lang_display": "Zaz",
            "lang_fullname": "Zazaca",
        },
        {
            "lang_id": 55,
            "lang_code": "br",
            "lang_display": "Bret",
            "lang_fullname": "Bretonca",
        },
        {
            "lang_id": 56,
            "lang_code": "eh",
            "lang_display": "EHind",
            "lang_fullname": "Eski Hintçe",
        },
        {
            "lang_id": 57,
            "lang_code": "pol",
            "lang_display": "Pol",
            "lang_fullname": "Polonya dili",
        },
        {
            "lang_id": 58,
            "lang_code": "gael",
            "lang_display": "Gael",
            "lang_fullname": "İskoç Gaelcesi",
        },
        {
            "lang_id": 59,
            "lang_code": "jap",
            "lang_display": "Jap",
            "lang_fullname": "Japonca",
        },
        {
            "lang_id": 60,
            "lang_code": "çağ",
            "lang_display": "ÇağT",
            "lang_fullname": "Çağatay Türkçesi",
        },
        {
            "lang_id": 61,
            "lang_code": "efr",
            "lang_display": "EFr",
            "lang_fullname": "Eski Fransızca",
        },
        {
            "lang_id": 62,
            "lang_code": "sl",
            "lang_display": "Slav",
            "lang_fullname": "Slavca",
        },
        {
            "lang_id": 63,
            "lang_code": "sogd",
            "lang_display": "Sogd",
            "lang_fullname": "Sogdca",
        },
        {
            "lang_id": 64,
            "lang_code": "sum",
            "lang_display": "Sumer",
            "lang_fullname": "Sumerce",
        },
        {
            "lang_id": 65,
            "lang_code": "hit",
            "lang_display": "Hit",
            "lang_fullname": "Hititçe",
        },
        {
            "lang_id": 66,
            "lang_code": "gal",
            "lang_display": "Gal",
            "lang_fullname": "Gal dili (Welsh)",
        },
        {
            "lang_id": 67,
            "lang_code": "özb",
            "lang_display": "Özb",
            "lang_fullname": "Özbekçe",
        },
    ],
    "nations": [
        {"nat_id": 1, "nat_code": "e", "nat_name": "Ermeni", "nat_gm": 1},
        {"nat_id": 2, "nat_code": "y", "nat_name": "Rum", "nat_gm": 1},
        {"nat_id": 3, "nat_code": "g", "nat_name": "Gürcü", "nat_gm": 0},
        {"nat_id": 4, "nat_code": "j", "nat_name": "Yahudi", "nat_gm": 1},
        {"nat_id": 5, "nat_code": "f", "nat_name": "Batı Avrupa", "nat_gm": 1},
        {"nat_id": 6, "nat_code": "k", "nat_name": "Kürt", "nat_gm": 0},
        {"nat_id": 7, "nat_code": "ar", "nat_name": "Arap", "nat_gm": 0},
        {"nat_id": 8, "nat_code": "s", "nat_name": "Süryani", "nat_gm": 1},
        {"nat_id": 9, "nat_code": "ah", "nat_name": "Ahıska", "nat_gm": 0},
        {"nat_id": 10, "nat_code": "az", "nat_name": "Azeri", "nat_gm": 0},
        {"nat_id": 11, "nat_code": "loc", "nat_name": "Yerel", "nat_gm": 0},
        {"nat_id": 12, "nat_code": "ha", "nat_name": "Hristiyan Arap", "nat_gm": 1},
        {"nat_id": 13, "nat_code": "al", "nat_name": "Alevi", "nat_gm": 0},
        {
            "nat_id": 14,
            "nat_code": "nu",
            "nat_name": "Nusayri (Arap Alevi)",
            "nat_gm": 1,
        },
        {"nat_id": 15, "nat_code": "drs", "nat_name": "Dersimli", "nat_gm": 0},
        {"nat_id": 16, "nat_code": "rg", "nat_name": "Rumeli göçmeni", "nat_gm": 0},
        {"nat_id": 17, "nat_code": "r", "nat_name": "Doğu Avrupa", "nat_gm": 1},
        {"nat_id": 18, "nat_code": "ç", "nat_name": "Çerkes", "nat_gm": 0},
        {"nat_id": 19, "nat_code": "h", "nat_name": "Hint", "nat_gm": 1},
        {"nat_id": 20, "nat_code": "kp", "nat_name": "Terekeme/Karapapak", "nat_gm": 0},
        {"nat_id": 21, "nat_code": "arn", "nat_name": "Arnavut", "nat_gm": 0},
        {"nat_id": 23, "nat_code": "oa", "nat_name": "Orta Asya/Afgan", "nat_gm": 0},
        {"nat_id": 24, "nat_code": "ro", "nat_name": "Romen", "nat_gm": 1},
        {"nat_id": 25, "nat_code": "lz", "nat_name": "Laz", "nat_gm": 0},
        {"nat_id": 27, "nat_code": "bo", "nat_name": "Boşnak", "nat_gm": 0},
        {"nat_id": 28, "nat_code": "gm", "nat_name": "Gayrimüslim", "nat_gm": 0},
        {"nat_id": 30, "nat_code": "rs", "nat_name": "Rus ve Sovyet", "nat_gm": 0},
        {
            "nat_id": 31,
            "nat_code": "yg",
            "nat_name": "Makedonya/Kosova/Bosna göçmeni",
            "nat_gm": 0,
        },
        {
            "nat_id": 32,
            "nat_code": "bg",
            "nat_name": "Bulgaristan göçmeni",
            "nat_gm": 0,
        },
        {"nat_id": 33, "nat_code": "z", "nat_name": "Zaza", "nat_gm": 0},
        {"nat_id": 34, "nat_code": "bu", "nat_name": "Bulgar", "nat_gm": 0},
        {"nat_id": 35, "nat_code": "ir", "nat_name": "İranlı", "nat_gm": 0},
        {"nat_id": 36, "nat_code": "uk", "nat_name": "Ukrayna", "nat_gm": 0},
        {"nat_id": 37, "nat_code": "çç", "nat_name": "Çeçen/Dağıstanlı", "nat_gm": 0},
        {"nat_id": 39, "nat_code": "t", "nat_name": "Türk", "nat_gm": 0},
        {"nat_id": 41, "nat_code": "tat", "nat_name": "Tatar", "nat_gm": 0},
        {
            "nat_id": 42,
            "nat_code": "yt",
            "nat_name": "Yeni Türk adı (1934-35)",
            "nat_gm": 0,
        },
        {"nat_id": 43, "nat_code": "uyg", "nat_name": "Uygur", "nat_gm": 0},
        {"nat_id": 44, "nat_code": "ak", "nat_name": "Alevi/Kürt", "nat_gm": 0},
    ],
}
